@@ -1,59 +1,56 @@
-#coding:utf-8
+# coding:utf-8
 """
-Основные объекты библиотеки: механизмы проверки прав, экшены, паки, контроллеры, кэш контроллеров
-+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+Основные объекты библиотеки: механизмы проверки прав, экшены, паки,
+контроллеры, кэш контроллеров
 """
-import abc
+from __future__ import absolute_import
+from __future__ import print_function
+
 from functools import wraps
-import inspect
+from logging import getLogger
+import abc
 import importlib
-import threading
+import inspect
 import re
+import threading
 import warnings
 
 from django import http
 from django.conf import settings
-from django.utils.importlib import import_module
+from m3_django_compat import get_installed_apps
+from six import iteritems
+from six import string_types
+from six import text_type
+from six import with_metaclass
+from six.moves import map
+import django
 
-try:
-    from django.utils.log import logger
-except ImportError:
-    from django.utils.log import getLogger
-    logger = getLogger('django')
+from .context import ActionContext
+from .context import ActionContextDeclaration
+from .context import ContextBuildingError
+from .context import CriticalContextBuildingError
+from .context import DeclarativeActionContext
+from .context import RequiredFailed
+from .exceptions import ActionException
+from .exceptions import ActionNotFoundException
+from .exceptions import ActionPackNotFoundException
+from .exceptions import ActionUrlIsNotDefined
+from .exceptions import ApplicationLogicException
+from .exceptions import ReinitException
+from .metrics import create_statsd_client
+from .results import ActionRedirectResult
+from .results import ActionResult
+from .results import BaseContextedResult
+from .results import HttpReadyResult
+from .results import JsonResult
+from .results import OperationResult
+from .results import PreJsonResult
+from .results import TextResult
+from .results import XMLResult
 
-from results import (
-    ActionResult,
-    PreJsonResult,
-    JsonResult,
-    HttpReadyResult,
-    TextResult,
-    XMLResult,
-    BaseContextedResult,
-    OperationResult,
-    ActionRedirectResult
-)
 
-from exceptions import (
-    ApplicationLogicException,
-    ActionException,
-    ActionNotFoundException,
-    ActionPackNotFoundException,
-    ReinitException,
-    ActionUrlIsNotDefined
-)
+logger = getLogger('django')
 
-import utils
-
-from context import (
-    ActionContext,
-    ActionContextDeclaration,
-    DeclarativeActionContext,
-    RequiredFailed,
-    ContextBuildingError,
-    CriticalContextBuildingError,
-)
-
-from metrics import create_statsd_client
 
 _STATSD_CLIENT = create_statsd_client(settings)
 
@@ -61,7 +58,8 @@ _STATSD_CLIENT = create_statsd_client(settings)
 ACD = ActionContextDeclaration
 
 
-_clean_url = lambda s: re.sub(r'^[/^]*(.*?)[$/]*$', r'\1', s)
+def _clean_url(s):
+    return re.sub(r'^[/^]*(.*?)[$/]*$', r'\1', s)
 
 
 def _import_by_path(path):
@@ -133,7 +131,7 @@ def _must_be_replaced_by(alternative):
             warnings.warn(
                 "'{clazz}.{method}' deprecated! Use '{alternative}'!".format(
                     clazz=class_name,
-                    method=fn.func_name,
+                    method=fn.__name__,
                     alternative=alternative
                 ), FutureWarning, 2)
             return fn(self, *args, **kwargs)
@@ -141,17 +139,16 @@ def _must_be_replaced_by(alternative):
     return wrapper
 
 
-#==============================================================================
+# =============================================================================
 # Абстрактный механизм проверки прав и его реализация,
 # проверяющая права через механизм django.contrib.auth.models.User.has_perm
-#==============================================================================
+# =============================================================================
 
 
-class AbstractPermissionChecker(object):
+class AbstractPermissionChecker(with_metaclass(abc.ABCMeta, object)):
     """
     Абстрактный механизм проверки прав
     """
-    __metaclass__ = abc.ABCMeta
 
     @abc.abstractmethod
     def has_action_permission(self, request, action, subpermission=None):
@@ -380,7 +377,7 @@ def _permission_checker_fabric():
         if path is None:
             # если backend не задан в настройках, то исходим из того,
             # подключены ли пользователи Django
-            if 'django.contrib.auth' in settings.INSTALLED_APPS:
+            if 'django.contrib.auth' in get_installed_apps():
                 result = AuthUserPermissionChecker
             else:
                 result = BypassPermissionChecker
@@ -403,9 +400,9 @@ def _permission_checker_fabric():
 _permission_checker = LazyContainer(_permission_checker_fabric)
 
 
-#========================== ИСКЛЮЧЕНИЯ ========================================
+# ========================== ИСКЛЮЧЕНИЯ =======================================
 
-#==============================================================================
+# =============================================================================
 class Action(object):
     u"""
     Базовый класс, от которого должны наследоваться все Action'ы в системе.
@@ -467,7 +464,7 @@ class Action(object):
         # метод оставлен для совместимости
         return self.has_perm(request)
 
-    #================= НОВЫЙ ИНТЕРФЕЙС ПРОВЕРКИ ПРАВ ==========================
+    # ================= НОВЫЙ ИНТЕРФЕЙС ПРОВЕРКИ ПРАВ =========================
     def has_perm(self, request, subpermission=None):
         """
         Интерфейсный метод проверки (под)прав экшна.
@@ -486,7 +483,7 @@ class Action(object):
         """
         # по-умолчанию код генерится backend`ом
         return _permission_checker.get_perm_code(self, subpermission)
-    #==========================================================================
+    # =========================================================================
 
     def pre_run(self, request, context):
         """
@@ -594,7 +591,7 @@ class Action(object):
         Возвращает полный путь от хоста до конечного экшена
         @deprecated: Дублирует absolute_url
         '''
-        #TODO: Переписать, т.к. этот код дублирует функции контроллера
+        # TODO: Переписать, т.к. этот код дублирует функции контроллера
         assert isinstance(self.controller, ActionController), (
             '%s is not actioncontroller in %s' % (self.controller, self))
         # Очищаем от мусора рег. выр.
@@ -708,7 +705,7 @@ class ActionPack(object):
                 pack = pack.parent
         else:
             path = [pack.url]
-        return '/'.join([pack.controller.url] + map(_clean_url, path))
+        return '/'.join([pack.controller.url] + list(map(_clean_url, path)))
 
     def get_permission_code(self):
         # метод оставлен для совместимости
@@ -723,7 +720,7 @@ class ActionPack(object):
 
         return self.has_perm(request, sub_code)
 
-    #================= НОВЫЙ ИНТЕРФЕЙС ПРОВЕРКИ ПРАВ ==========================
+    # ================= НОВЫЙ ИНТЕРФЕЙС ПРОВЕРКИ ПРАВ =========================
     def has_perm(self, request, permission):
         """
         Интерфейсный метод проверки подправ пака.
@@ -742,7 +739,7 @@ class ActionPack(object):
         """
         # по-умолчанию код генерится backend`ом
         return _permission_checker.get_perm_code(self, permission)
-    #==========================================================================
+    # =========================================================================
 
     def pre_run(self, request, context):
         """
@@ -860,9 +857,9 @@ class ActionController(object):
             else super(ActionController, self).__str__()
         )
 
-    #==========================================================================
+    # =========================================================================
     # Методы для быстрого поиска экшенов и паков по разным атрибутам
-    #==========================================================================
+    # =========================================================================
     def _add_action_to_search_dicts(self, action, full_path):
         """ Добавляет экшен в словари для быстрого доступа """
         assert isinstance(action, Action)
@@ -884,14 +881,14 @@ class ActionController(object):
         """
         self._actions_by_name.clear()
         self._actions_by_type.clear()
-        for full_path, v in self._url_patterns.iteritems():
+        for full_path, v in iteritems(self._url_patterns):
             _, action = v
             self._add_action_to_search_dicts(action, full_path)
         # Обновлять _packs_by_name и _packs_by_type не нужно!
 
-    #==========================================================================
+    # =========================================================================
     # Методы формирующие иерархию экшенов и паков
-    #==========================================================================
+    # =========================================================================
     def _load_class(self, full_path):
         '''
         По полному пути загружает и созвращает класс
@@ -901,7 +898,7 @@ class ActionController(object):
         mod_name = full_path[:dot]
         pack_name = full_path[dot + 1:]
         # Пробуем загрузить
-        mod = import_module(mod_name)
+        mod = importlib.import_module(mod_name)
         clazz = getattr(mod, pack_name)
         return clazz
 
@@ -976,7 +973,7 @@ class ActionController(object):
             raise
         except ContextBuildingError as e:
             # некритичную ошибку - показываем пользователю
-            return OperationResult.by_message(unicode(e))
+            return OperationResult.by_message(text_type(e))
         except RequiredFailed as e:
             # если контекст неправильный, то возвращаем
             # фейльный результат операции
@@ -1041,9 +1038,10 @@ class ActionController(object):
             with _STATSD_CLIENT(self, request):
                 try:
                     result = self._invoke(request, action, stack)
-                except:
+                except:  # noqa
                     if settings.DEBUG:
-                    # Записывает сообщение в логгер если включен тестовый режим
+                        # Записывает сообщение в логгер если включен тестовый
+                        # режим
                         logger.exception(
                             u'ActionController.process_request: '
                             u'перехвачена необработанная ошибка'
@@ -1087,9 +1085,9 @@ class ActionController(object):
         else:
             return ActionContext()
 
-    #==========================================================================
+    # =========================================================================
     # Методы, предназначенные для поиска экшенов и паков в контроллере
-    #==========================================================================
+    # =========================================================================
     @_must_be_replaced_by('ControllerCache.find_pack')
     def find_pack(self, type):
         return self._find_pack(type)
@@ -1099,7 +1097,7 @@ class ActionController(object):
         return self._find_action(type)
 
     def _find_pack(self, pack):
-        if isinstance(pack, basestring):
+        if isinstance(pack, string_types):
             inst = self._packs_by_name.get(pack)
         elif inspect.isclass(pack):
             inst = self._packs_by_type.get(pack)
@@ -1108,7 +1106,7 @@ class ActionController(object):
         return inst
 
     def _find_action(self, action):
-        if isinstance(action, basestring):
+        if isinstance(action, string_types):
             inst, _ = self._actions_by_name.get(action, (None, None))
         elif inspect.isclass(action):
             inst, _ = self._actions_by_type.get(action, (None, None))
@@ -1137,10 +1135,10 @@ class ActionController(object):
         """
         return self._nodes_by_perm.get(perm)
 
-    #==========================================================================
+    # =========================================================================
     # Методы, предназначенные для добавления/изменения/удаления
     # пакетов действий в контроллер
-    #==========================================================================
+    # =========================================================================
     def append_pack(self, pack):
         """
         Добавляет пак в контроллер.
@@ -1153,8 +1151,8 @@ class ActionController(object):
                 u'Pack must be an instance of ActionPack subclass!')
 
         # пак может быть перегруже
-        if pack.short_name in ControllerCache.overrides:
-            pack = ControllerCache.overrides[pack.short_name]
+        if pack.get_short_name() in ControllerCache.overrides:
+            pack = ControllerCache.overrides[pack.get_short_name()]
 
         self._build_pack_node(pack, [])
         if pack not in self.top_level_packs:
@@ -1232,7 +1230,7 @@ class ActionController(object):
         left_packs = []
         right_packs = []
 
-        for url, value in self._url_patterns.iteritems():
+        for url, value in iteritems(self._url_patterns):
             packs_list, final_action = value
 
             # Поиск пака и соседей в списке
@@ -1321,7 +1319,7 @@ class ActionController(object):
         new_patterns = {}
         current_packs_slice = None
 
-        for url, value in self._url_patterns.iteritems():
+        for url, value in iteritems(self._url_patterns):
             packs_list, final_action = value
 
             # Поиск исходного пака и экшена в нём
@@ -1361,11 +1359,11 @@ class ActionController(object):
         Отладочный метод.
         Выводит в консоль список всех адрес зарегистрированных в контроллере.
         '''
-        print '==== CONTROLLER WITH URL: %s ======' % self.url
+        print('==== CONTROLLER WITH URL: %s ======' % self.url)
         for key in sorted(self._url_patterns.keys()):
-            print key
-        print
-        print 'Total patterns %s' % len(self._url_patterns.keys())
+            print(key)
+        print()
+        print('Total patterns %s' % len(list(self._url_patterns.keys())))
 
     def get_action_by_url(self, url):
         """
@@ -1397,7 +1395,7 @@ class ActionController(object):
         '''
         Возвращение всех паков в контроллере
         '''
-        return self._packs_by_name.values()
+        return list(self._packs_by_name.values())
 
     def reset(self):
         '''
@@ -1443,15 +1441,15 @@ class ControllerCache(object):
 
     overrides = {}
 
-    #==========================================================================
+    # =========================================================================
     # Методы, предназначенные для поиска экшенов
     # и паков во всех контроллерах системы
-    #==========================================================================
+    # =========================================================================
 
     @classmethod
     def get_action_url(cls, type):
         """ Возвращает URL экшена *type* по его имени или классу """
-        assert isinstance(type, basestring) or issubclass(type, Action)
+        assert isinstance(type, string_types) or issubclass(type, Action)
         cls.populate()
         for cont in cls._controllers:
             url = cont.get_action_url(type)
@@ -1473,7 +1471,7 @@ class ControllerCache(object):
         """
         if inspect.isclass(pack):
             name = pack.get_short_name()
-        elif isinstance(pack, str) and '.' in pack:
+        elif isinstance(pack, string_types) and '.' in pack:
             name = pack
         else:
             raise ValueError(
@@ -1530,7 +1528,7 @@ class ControllerCache(object):
             if node:
                 return node
 
-    #==========================================================================
+    # =========================================================================
     @classmethod
     def _self_test(cls):
         """
@@ -1627,17 +1625,17 @@ class ControllerCache(object):
 
             cls.overrides = {}
             procs = []
-            for app_name in settings.INSTALLED_APPS:
+            for app_name in get_installed_apps():
                 try:
-                    module = import_module('.app_meta', app_name)
-                except ImportError, err:
+                    module = importlib.import_module('.app_meta', app_name)
+                except ImportError as err:
                     if err.args[0].find('No module named') == -1:
                         raise
                     continue
 
                 # расширение словаря overridde'ов
                 for original_cls, new_inst in (
-                    getattr(module, 'action_pack_overrides', {}).iteritems()
+                    iteritems(getattr(module, 'action_pack_overrides', {}))
                 ):
                     if inspect.isclass(original_cls):
                         original_cls = original_cls.get_short_name()
@@ -1663,7 +1661,7 @@ class ControllerCache(object):
         Отладочный метод.
         Выводит в консоль адреса всех контроллеров зарегистрированных в кэше.
         '''
-        print '------------ CONTROLLER CACHE DUMP ------------'
+        print('------------ CONTROLLER CACHE DUMP ------------')
         for cont in cls._controllers:
             cont.dump_urls()
 
