@@ -1,24 +1,23 @@
-#coding:utf-8
-"""
-Экшены для работы в асинхронном режиме
-++++++++++++++++++++++++++++++++++++++
-"""
-__author__ = 'ZIgi'
+# coding:utf-8
+u"""Экшены для работы в асинхронном режиме."""
+from __future__ import absolute_import
 
-from abc import ABCMeta, abstractmethod
+from abc import ABCMeta
+from abc import abstractmethod
+from logging import getLogger
 from threading import Thread
 import json
 
 from django import http
-from django.conf import settings
-try:
-    from django.utils.log import logger
-except ImportError:
-    from django.utils.log import getLogger
-    logger = getLogger('django')
-
-from m3.actions import Action, ACD
+from m3.actions import ACD
+from m3.actions import Action
 from m3.actions.results import ActionResult
+from m3_django_compat import get_installed_apps
+from six import with_metaclass
+
+
+logger = getLogger('django')
+
 
 # !!!!!
 # для работы данного модуля необходимо наличие приложения 'm3_mutex'
@@ -27,7 +26,7 @@ from m3.actions.results import ActionResult
 # TODO: переделать по правильному - платформа не должна импортировать
 # модули контрибов
 
-if not 'm3_mutex' in settings.INSTALLED_APPS:
+if 'm3_mutex' not in get_installed_apps():
     # При сборке документации внешняя Django ничего не знает про m3_mutex
     logger.warning(
         u'For working async operations "m3_mutex" '
@@ -44,7 +43,7 @@ except ImportError:
     logger.warning(u'm3_mutex import error')
 
 
-class IBackgroundWorker(Thread):
+class IBackgroundWorker(with_metaclass(ABCMeta, Thread)):
     '''
     Абстрактный класс для исполнения кода в фоновом режиме.
     Соответсвующие методы должны быть определены разработчиком.
@@ -58,7 +57,6 @@ class IBackgroundWorker(Thread):
     (например если есть нужда использовать мутекс на уровне
     нескольких инстансов приложений)
     '''
-    __metaclass__ = ABCMeta
 
     def __init__(self, boundary='', context=None, *args, **kwargs):
         super(IBackgroundWorker, self).__init__()
@@ -223,7 +221,7 @@ class AsyncOperationResult(ActionResult):
             'value': self.value,
             'alive': self.alive,
         })
-        return http.HttpResponse(data, mimetype='application/json')
+        return http.HttpResponse(data, content_type='application/json')
 
 
 class AsyncAction(Action):
