@@ -1,19 +1,21 @@
-#coding:utf-8
-'''
-Модуль, реализущий работу с контекстом выполнения операции
-++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-'''
-#author: akvarats
+# coding:utf-8
+u"""Модуль, реализущий работу с контекстом выполнения операции."""
+from __future__ import absolute_import
+
+from decimal import Decimal
+from logging import getLogger
 import datetime
 import json
-from decimal import Decimal
 
-from django.utils.encoding import force_unicode
-try:
-    from django.utils.log import logger
-except ImportError:
-    from django.utils.log import getLogger
-    logger = getLogger('django')
+from django.utils.encoding import force_text
+from m3_django_compat import get_request_params
+from six import iteritems
+from six import python_2_unicode_compatible
+from six import string_types
+from six import text_type
+
+
+logger = getLogger('django')
 
 
 def _date2str(*args):
@@ -21,7 +23,8 @@ def _date2str(*args):
     from m3 import date2str
     return date2str(*args)
 
-#============================= ИСКЛЮЧЕНИЯ =====================================
+
+# ============================= ИСКЛЮЧЕНИЯ ====================================
 class ActionContextException(Exception):
     """ Базовый класс для исключений контекста """
     pass
@@ -54,6 +57,7 @@ class ConversionFailed(ActionContextException):
             self.value, self.type)
 
 
+@python_2_unicode_compatible
 class ContextBuildingError(ActionContextException):
     u"""
     Ошибка построения контекста
@@ -82,7 +86,7 @@ class ContextBuildingError(ActionContextException):
 
     __str__ = __repr__
 
-    def __unicode__(self):
+    def __str__(self):
         log = []
         for title, data in (
             (u"Отсутствуют обязательные параметры:", self.requiremets),
@@ -101,7 +105,7 @@ class CriticalContextBuildingError(ContextBuildingError):
     pass
 
 
-#================================== ПАРСЕРЫ ===================================
+# ================================== ПАРСЕРЫ ==================================
 def _make_datetime_parser(extractor, formats):
     def parse(value):
         for (fmt, length) in formats:
@@ -172,8 +176,8 @@ _time_parser = _make_datetime_parser(
 
 
 _PARSERS = {
-    str: _make_simple_parser(unicode),  # Иду на поводу у хомячков (FIXME)
-    unicode: _make_simple_parser(unicode),
+    str: _make_simple_parser(text_type),  # Иду на поводу у хомячков (FIXME)
+    text_type: _make_simple_parser(text_type),
     int: _make_simple_parser(int),
     float: _make_simple_parser(float),
     Decimal: _make_simple_parser(Decimal),
@@ -208,7 +212,12 @@ _PARSERS = {
 }
 
 
-#================================== КЛАССЫ ====================================
+# ================================== КЛАССЫ ===================================
+
+# "Стражник" для значения по умолчанию ActionContextDeclaration.
+_none = object()
+
+
 class ActionContextDeclaration(object):
     u"""
     Класс, который определяет правило извлечения параметра из
@@ -227,7 +236,7 @@ class ActionContextDeclaration(object):
         необходимо для сообщений об ошибках
     """
     def __init__(
-            self, name='', default=None, type=None,
+            self, name='', default=_none, type=None,
             required=False, verbose_name='', *args, **kwargs):
         assert type, 'type must be defined!'
         self.name = name
@@ -284,7 +293,7 @@ class ActionContext(object):
                     for e in elements
                 ]
             else:
-                if not arg_type in _PARSERS:
+                if arg_type not in _PARSERS:
                     raise TypeError('Unknown parser "%r"!' % arg_type)
                 value = _PARSERS[arg_type](raw_value)
         except AssertionError:
@@ -314,8 +323,7 @@ class ActionContext(object):
         key = value = ptype = None
         try:
             # переносим параметры в контекст из запроса
-            for key in request.REQUEST:
-                value = request.REQUEST[key]
+            for key, value in iteritems(get_request_params(request)):
                 # Пустые параметры не конвертируем,
                 # т.к. они могут вызвать ошибку
                 if not value:
@@ -331,7 +339,7 @@ class ActionContext(object):
         except IOError as err:
             # В некоторых браузерах (предполагается что в ie)
             # происходит следующие:
-            # request.REQUEST читается и в какой-то момент связь прекращается
+            # REQUEST читается и в какой-то момент связь прекращается
             # из-за того, что браузер разрывает соединение,
             # в следствии этого происходит ошибка
             # IOError: request data read error
@@ -347,7 +355,7 @@ class ActionContext(object):
 
         # переносим обязательные параметры, которые не встретились в запросе
         for rule in rules if rules else []:
-            if rule.required and rule.default is not None and (
+            if rule.required and rule.default is not _none and (
                     not params[rule.name][1]):
                 # если параметр не передан в запросе, но
                 # он является обязательным и задано значение по умолчанию,
@@ -368,7 +376,7 @@ class ActionContext(object):
         if not rules:
             return
         for rule in rules:
-            if rule.required and getattr(self, rule.name, None) is None:
+            if rule.required and getattr(self, rule.name, _none) is _none:
                 raise ActionContext.RequiredFailed(rule.human_name())
 
     def json(self):
@@ -384,7 +392,7 @@ class ActionContext(object):
             elif isinstance(obj, datetime.time):
                 result = _date2str(obj, '%H:%M')
             else:
-                result = force_unicode(obj)
+                result = force_text(obj)
 
             return result
 
@@ -392,7 +400,7 @@ class ActionContext(object):
         # и при этом только те, которые не callable
         data = dict(
             (k, v)
-            for k, v in self.__dict__.iteritems()
+            for k, v in iteritems(self.__dict__)
             if not (
                 k.startswith('_') or
                 callable(v)
@@ -418,7 +426,7 @@ class ActionContext(object):
         return result
 
 
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 class DeclarativeActionContext(ActionContext):
     """
     ActionContext, использующий декларативное описание контекста
@@ -440,7 +448,7 @@ class DeclarativeActionContext(ActionContext):
         'int': int,
         'float': float,
         'str': str,
-        'unicode': unicode,
+        'unicode': text_type,
         'decimal': Decimal,
     }
 
@@ -465,7 +473,7 @@ class DeclarativeActionContext(ActionContext):
         # определяем режим, если правилла описаны парой
         if isinstance(rules, tuple):
             # режим
-            mode = request.REQUEST.get(rules[0])
+            mode = get_request_params(request).get(rules[0])
             try:
                 # правила для конкретного режима
                 rules = rules[1][mode]
@@ -479,7 +487,7 @@ class DeclarativeActionContext(ActionContext):
         errors = []
         only_noncritical = True
 
-        for key, parser_data in rules.iteritems():
+        for key, parser_data in iteritems(rules):
             parser = parser_data['type']
             if not callable(parser):
                 try:
@@ -492,7 +500,7 @@ class DeclarativeActionContext(ActionContext):
 
             add_error_to = None
             try:
-                val = request.REQUEST.get(key)
+                val = get_request_params(request).get(key)
                 if val is None:
                     if 'default' in parser_data:
                         val = parser_data['default']
@@ -549,5 +557,5 @@ class DeclarativeActionContext(ActionContext):
         return isinstance(data, dict) or (
             isinstance(data, tuple) and
             len(data) == 2 and
-            isinstance(data[0], basestring)
+            isinstance(data[0], string_types)
         )
