@@ -1,24 +1,25 @@
-#coding:utf-8
-"""
-Created on 29.01.2011
+# coding:utf-8
+from __future__ import absolute_import
 
-@author: akvarats
-"""
-
-from django.db import transaction
 from django.dispatch import Signal
-
 from m3 import RelatedError
-from m3.actions import (
-    ActionPack, Action, PreJsonResult, OperationResult, ACD, utils)
+from m3.actions import ACD
+from m3.actions import Action
+from m3.actions import ActionPack
+from m3.actions import OperationResult
+from m3.actions import PreJsonResult
+from m3.actions import utils
+from m3.actions.interfaces import IMultiSelectablePack
 from m3.actions.packs import ListDeleteRowAction
 from m3.actions.results import ActionResult
-from m3.actions.interfaces import IMultiSelectablePack
-from m3_ext.ui.results import ExtUIScriptResult
-from m3_ext.ui.misc.store import ExtJsonStore
-from m3_ext.ui.windows.complex import ExtDictionaryWindow
+from m3.db import BaseObjectModel
+from m3.db import safe_delete
+from m3_django_compat import atomic
+from m3_django_compat import get_request_params
 from m3_ext.ui.containers import ExtPagingBar
-from m3.db import BaseObjectModel, safe_delete
+from m3_ext.ui.misc.store import ExtJsonStore
+from m3_ext.ui.results import ExtUIScriptResult
+from m3_ext.ui.windows.complex import ExtDictionaryWindow
 
 
 class TreeGetNodesAction(Action):
@@ -116,7 +117,7 @@ class ListGetRowsAction(Action):
         parent_id = utils.extract_int(request, 'id')
         offset = utils.extract_int(request, 'start')
         limit = utils.extract_int(request, 'limit')
-        filter = request.REQUEST.get('filter')
+        filter = get_request_params(request).get('filter')
         result = self.parent.get_rows(
             request, context, parent_id, offset, limit, filter)
         return PreJsonResult(result)
@@ -232,9 +233,12 @@ class TreeEditNodeWindowAction(Action):
             win.make_read_only(
                 access_off=True, exclude_list=['close_btn', 'cancel_btn'])
 
-        # У окна может быть процедура доп. конфигурации под конкретный справочник
-        if hasattr(win, 'configure_for_dictpack') and callable(
-                win.configure_for_dictpack):
+        # У окна может быть процедура доп. конфигурации под конкретный
+        # справочник
+        if (
+            hasattr(win, 'configure_for_dictpack') and
+            callable(win.configure_for_dictpack)
+        ):
             win.configure_for_dictpack(
                 action=self, pack=self.parent,
                 request=request, context=context)
@@ -549,7 +553,7 @@ class BaseTreeDictionaryActions(ActionPack, IMultiSelectablePack):
             self.delete_node_action
         ])
 
-    #========================== ДЕРЕВО ===========================
+    # ========================== ДЕРЕВО ===========================
 
     def get_nodes(self, parent_id, filter):
         raise NotImplementedError()
@@ -572,15 +576,15 @@ class BaseTreeDictionaryActions(ActionPack, IMultiSelectablePack):
         """
         return self.list_window_action
 
-    #================ ФУНКЦИИ ВОЗВРАЩАЮЩИЕ АДРЕСА ===============
-    #ISelectablePack
+    # ================ ФУНКЦИИ ВОЗВРАЩАЮЩИЕ АДРЕСА ===============
+    # ISelectablePack
     def get_select_url(self):
         """
         Возвращает адрес формы списка элементов справочника.
         """
         return self.select_window_action.get_absolute_url()
 
-    #IMultiSelectablePack
+    # IMultiSelectablePack
     def get_multi_select_url(self):
         return self.multi_select_window_action.get_absolute_url()
 
@@ -590,7 +594,7 @@ class BaseTreeDictionaryActions(ActionPack, IMultiSelectablePack):
         """
         return self.list_window_action.get_absolute_url()
 
-    #ISelectablePack
+    # ISelectablePack
     def get_edit_url(self):
         """
         Возвращает адрес формы редактирования элемента справочника.
@@ -621,7 +625,7 @@ class BaseTreeDictionaryActions(ActionPack, IMultiSelectablePack):
         """
         return self.nodes_like_rows_action.get_absolute_url()
 
-    #ISelectablePack
+    # ISelectablePack
     def get_autocomplete_url(self):
         """
         Получить адрес для запроса элементов
@@ -629,7 +633,7 @@ class BaseTreeDictionaryActions(ActionPack, IMultiSelectablePack):
         """
         return self.get_nodes_like_rows_url()
 
-    #=================== ИЗМЕНЕНИЕ ДАННЫХ =======================
+    # =================== ИЗМЕНЕНИЕ ДАННЫХ =======================
 
     def get_rows(self, offset, limit, filter, parent_id):
         raise NotImplementedError()
@@ -646,7 +650,7 @@ class BaseTreeDictionaryActions(ActionPack, IMultiSelectablePack):
     def delete_row(self, obj):
         raise NotImplementedError()
 
-    #ISelectablePack
+    # ISelectablePack
     def get_display_text(self, key, attr_name=None):
         """
         Получить отображаемое значение записи
@@ -654,14 +658,14 @@ class BaseTreeDictionaryActions(ActionPack, IMultiSelectablePack):
         """
         raise NotImplementedError()
 
-    #ISelectablePack
+    # ISelectablePack
     def get_record(self, key):
         """
         Получить записи по ключу key
         """
         raise NotImplementedError()
 
-    #IMultiSelectablePack
+    # IMultiSelectablePack
     def get_display_dict(self, key, value_field='id', display_field='name'):
         """
         Получить список словарей, необходимый для представления выбранных
@@ -669,21 +673,21 @@ class BaseTreeDictionaryActions(ActionPack, IMultiSelectablePack):
         """
         raise NotImplementedError()
 
-    #============ ДЛЯ ИЗМЕНЕНИЯ ОКОН ВЫБОРА НА ХОДУ ==============
+    # ============ ДЛЯ ИЗМЕНЕНИЯ ОКОН ВЫБОРА НА ХОДУ ==============
     def get_select_window(self, win):
         return win
 
     def get_list_window(self, win):
         return win
 
-    #======================= Drag&Drop ===========================
+    # ======================= Drag&Drop ===========================
     def drag_node(self, id, dest_id):
         raise NotImplementedError()
 
     def drag_item(self, id, dest_id):
         raise NotImplementedError()
 
-    #============ ДЛЯ ИЗМЕНЕНИЯ ОКОН РЕДАКТИРОВАНИЯ НА ХОДУ ======
+    # ============ ДЛЯ ИЗМЕНЕНИЯ ОКОН РЕДАКТИРОВАНИЯ НА ХОДУ ======
     def get_edit_window(self, win):
         return win
 
@@ -702,23 +706,38 @@ class BaseTreeDictionaryModelActions(BaseTreeDictionaryActions):
     # Поля для поиска по умолчанию.
     DEFAULT_FILTER_FIELDS = ['code', 'name']
 
+    # -------------------------------------------------------------------------
     # Настройки для модели дерева
-    tree_model = None  # Сама модель дерева
-    tree_filter_fields = []  # Поля по которым производится поиск в дереве
-    tree_columns = []  # Список из кортежей с параметрами выводимых в дерево колонок
-    tree_parent_field = 'parent'  # Имя поля ссылающегося на группу
-    tree_readonly = False  # Если истина, то адреса экшенов дереву не назначаются
-    tree_order_field = ''
 
+    # Сама модель дерева
+    tree_model = None
+    # Поля по которым производится поиск в дереве
+    tree_filter_fields = []
+    # Список из кортежей с параметрами выводимых в дерево колонок
+    tree_columns = []
+    # Имя поля ссылающегося на группу
+    tree_parent_field = 'parent'
+    # Если истина, то адреса экшенов дереву не назначаются
+    tree_readonly = False
+    tree_order_field = ''
+    # -------------------------------------------------------------------------
     # Настройки модели списка
-    list_model = None  # Не обязательная модель списка связанного с деревом
-    list_columns = []  # Список из кортежей с параметрами выводимых в грид колонок
-    filter_fields = []  # Поля по которым производится поиск в списке
-    list_parent_field = 'parent'  # Имя поля ссылающегося на группу
-    list_readonly = False  # Если истина, то адреса экшенов гриду не назначаются
-    list_drag_and_drop = True  # Разрешает перетаскивание элементов из грида в другие группы дерева
+
+    # Не обязательная модель списка связанного с деревом
+    list_model = None
+    # Список из кортежей с параметрами выводимых в грид колонок
+    list_columns = []
+    # Поля по которым производится поиск в списке
+    filter_fields = []
+    # Имя поля ссылающегося на группу
+    list_parent_field = 'parent'
+    # Если истина, то адреса экшенов гриду не назначаются
+    list_readonly = False
+    # Разрешает перетаскивание элементов из грида в другие группы дерева
+    list_drag_and_drop = True
     list_order_field = ''
     list_paging = True
+    # -------------------------------------------------------------------------
 
     # Порядок сортировки элементов списка. Работает следующим образом:
     # 1. Если в list_columns модели списка есть поле code,
@@ -945,7 +964,7 @@ class BaseTreeDictionaryModelActions(BaseTreeDictionaryActions):
         # Такая реализация обусловлена тем,
         # что IntegrityError невозможно отловить
         # до завершения транзакции, и приходится оборачивать транзакцию.
-        @transaction.commit_on_success
+        @atomic
         def delete_row_in_transaction(self, objs):
             message = ''
             if len(objs) == 0:
@@ -959,7 +978,7 @@ class BaseTreeDictionaryModelActions(BaseTreeDictionaryActions):
                     ):
                         try:
                             obj.safe_delete()
-                        except RelatedError, e:
+                        except RelatedError as e:
                             message = e.args[0]
                     else:
                         if not safe_delete(obj):
@@ -972,7 +991,7 @@ class BaseTreeDictionaryModelActions(BaseTreeDictionaryActions):
         # Тут пытаемся поймать ошибку из транзакции.
         try:
             return delete_row_in_transaction(self, objs)
-        except Exception, e:
+        except Exception as e:
             # Встроенный в Django IntegrityError не генерируется.
             # Кидаются исключения специфичные для каждого драйвера БД.
             # Но по спецификации PEP 249 все они называются IntegrityError
@@ -1034,7 +1053,7 @@ class BaseTreeDictionaryModelActions(BaseTreeDictionaryActions):
             row.save()
         return OperationResult()
 
-    #ISelectablePack
+    # ISelectablePack
     def get_edit_url(self):
         """
         Получить адрес для запроса диалога редактирования выбранного элемента
@@ -1050,7 +1069,7 @@ class BaseTreeDictionaryModelActions(BaseTreeDictionaryActions):
             return self.get_edit_node_url()
         return None
 
-    #ISelectablePack
+    # ISelectablePack
     def get_display_text(self, key, attr_name=None):
         """
         Получить отображаемое значение записи
@@ -1069,7 +1088,7 @@ class BaseTreeDictionaryModelActions(BaseTreeDictionaryActions):
                 return text
         return None
 
-    #ISelectablePack
+    # ISelectablePack
     def get_record(self, key):
         """ Получить запись по ключу key """
         row = None
@@ -1079,7 +1098,7 @@ class BaseTreeDictionaryModelActions(BaseTreeDictionaryActions):
             row = self.get_node(key)
         return row
 
-    #IMultiSelectablePack
+    # IMultiSelectablePack
     def get_display_dict(self, key, value_field='id', display_field='name'):
         """
         Получить список словарей, необходимый для представления выбранных
@@ -1102,10 +1121,11 @@ class BaseTreeDictionaryModelActions(BaseTreeDictionaryActions):
                     })
         return items
 
-#===============================================================================
+# =============================================================================
 # Сигналы, которые посылаются в процессе
 # работы подсистемы древовидных справочника
-#==============================================================================
+# =============================================================================
+
 
 # сигнал о том, что узлы дерева иерархического справочника подготовлены
 nodes_prepared = Signal(providing_args=['nodes'])
