@@ -1,35 +1,38 @@
-#coding: utf-8
-"""
-Паки и экшены для работы со справочниками
-+++++++++++++++++++++++++++++++++++++++++
-"""
-from django.db import transaction
-from django.conf import settings
-try:
-    from django.utils.log import logger
-except ImportError:
-    from django.utils.log import getLogger
-    logger = getLogger('django')
+# coding: utf-8
+u"""Паки и экшены для работы со справочниками."""
+from __future__ import absolute_import
+
+from logging import getLogger
 
-from m3.actions import (
-    ActionPack, Action, PreJsonResult, OperationResult, ACD
-)
-from m3_ext.ui.windows.complex import ExtDictionaryWindow
-from m3_ext.ui.misc.store import ExtJsonStore
-from m3_ext.ui.containers import ExtPagingBar
-from m3_ext.ui.results import ExtUIScriptResult
-from m3.actions import utils
-from m3.actions.results import ActionResult
-from m3.db import BaseObjectModel, safe_delete
 from m3 import RelatedError
+from m3.actions import ACD
+from m3.actions import Action
+from m3.actions import ActionPack
+from m3.actions import OperationResult
+from m3.actions import PreJsonResult
+from m3.actions import utils
+from m3.actions.interfaces import ISelectablePack
+from m3.actions.results import ActionResult
+from m3.db import BaseObjectModel
+from m3.db import safe_delete
+from m3_django_compat import atomic
+from m3_django_compat import get_installed_apps
+from m3_django_compat import get_request_params
+from m3_ext.ui.containers import ExtPagingBar
+from m3_ext.ui.misc.store import ExtJsonStore
+from m3_ext.ui.results import ExtUIScriptResult
+from m3_ext.ui.windows.complex import ExtDictionaryWindow
+
+
+logger = getLogger('django')
+
 
 try:
-    from m3_audit import AuditManager
+    from m3_audit.manager import AuditManager
 except ImportError:
     # При сборке документации, внешняя Django ничего не знает про m3_audit
     logger.warning('m3_audit import error')
 
-from m3.actions.interfaces import ISelectablePack
 
 MSG_DOESNOTEXISTS = (
     u'Запись справочника с id=%s не найдена в базе данных.<br/>'
@@ -136,7 +139,7 @@ class DictSelectWindowAction(DictListWindowAction):
 
         # M prefer 12.12.10 >
         # win.column_name_on_select = "name"
-        #-----:
+        # -----:
         win.column_name_on_select = base.column_name_on_select
         # prefer <
 
@@ -237,9 +240,10 @@ class DictRowsAction(Action):
     def run(self, request, context):
         offset = utils.extract_int(request, 'start')
         limit = utils.extract_int(request, 'limit')
-        filter = request.REQUEST.get('filter')
-        direction = request.REQUEST.get('dir')
-        user_sort = request.REQUEST.get('sort')
+        request_params = get_request_params(request)
+        filter = request_params.get('filter')
+        direction = request_params.get('dir')
+        user_sort = request_params.get('sort')
         if direction == 'DESC':
             user_sort = '-' + user_sort
         dict_list = []
@@ -329,7 +333,7 @@ class DictSaveAction(Action):
             # узкое место. после того, как мы переделаем работу экшенов,
             # имя параметра с идентификатором запси может уже называться не
             # id
-            if 'm3_audit' in settings.INSTALLED_APPS:
+            if 'm3_audit' in get_installed_apps():
                 AuditManager().write(
                     'dict-changes',
                     user=request.user,
@@ -356,7 +360,7 @@ class ListDeleteRowAction(Action):
         result = self.parent.delete_row(objs)
         if (isinstance(result, OperationResult) and
                 result.success is True and
-                'm3_audit' in settings.INSTALLED_APPS):
+                'm3_audit' in get_installed_apps()):
             for obj in objs:
                 AuditManager().write(
                     'dict-changes',
@@ -479,7 +483,7 @@ class BaseDictionaryActions(ActionPack, ISelectablePack):
         # Исключение перехватываемое в экшенах, если объект не найден
         self._nofound_exception = ObjectNotFound
 
-    #==================== ФУНКЦИИ ВОЗВРАЩАЮЩИЕ АДРЕСА =====================
+    # ==================== ФУНКЦИИ ВОЗВРАЩАЮЩИЕ АДРЕСА =====================
     def get_list_url(self):
         """
         Возвращает адрес формы списка элементов справочника.
@@ -487,7 +491,7 @@ class BaseDictionaryActions(ActionPack, ISelectablePack):
         """
         return self.list_window_action.get_absolute_url()
 
-    #ISelectablePack
+    # ISelectablePack
     def get_select_url(self):
         """
         Возвращает адрес формы списка элементов справочника.
@@ -495,7 +499,7 @@ class BaseDictionaryActions(ActionPack, ISelectablePack):
         """
         return self.select_window_action.get_absolute_url()
 
-    #ISelectablePack
+    # ISelectablePack
     def get_edit_url(self):
         """
         Возвращает адрес формы редактирования элемента справочника.
@@ -508,7 +512,7 @@ class BaseDictionaryActions(ActionPack, ISelectablePack):
         """
         return self.rows_action.get_absolute_url()
 
-    #ISelectablePack
+    # ISelectablePack
     def get_autocomplete_url(self):
         """
         Возвращает адрес по которому запрашиваются элементы
@@ -516,7 +520,7 @@ class BaseDictionaryActions(ActionPack, ISelectablePack):
         """
         return self.get_rows_url()
 
-    #==================== ФУНКЦИИ ВОЗВРАЩАЮЩИЕ ДАННЫЕ =====================
+    # ==================== ФУНКЦИИ ВОЗВРАЩАЮЩИЕ ДАННЫЕ =====================
     def get_rows(self, offset, limit, filter, user_sort=''):
         """
         Метод который возвращает записи грида в виде
@@ -566,7 +570,7 @@ class BaseDictionaryActions(ActionPack, ISelectablePack):
         """
         raise NotImplementedError()
 
-    #ISelectablePack
+    # ISelectablePack
     def get_display_text(self, key, attr_name=None):
         """
         Получить отображаемое значение записи
@@ -582,14 +586,14 @@ class BaseDictionaryActions(ActionPack, ISelectablePack):
             else:
                 return text
 
-    #ISelectablePack
+    # ISelectablePack
     def get_record(self, key):
         """
         Получить значение записи по ключу key
         """
         return self.get_row(key)
 
-    #====================== РАБОТА С ОКНАМИ ===============================
+    # ====================== РАБОТА С ОКНАМИ ===============================
     def get_list_window(self, win):
         """
         Возвращает настроенное окно типа "Список" справочника
@@ -636,7 +640,10 @@ class BaseDictionaryModelActions(BaseDictionaryActions):
         '''
         Возвращает данные для грида справочника
         '''
-        sort_order = user_sort.split(',') if user_sort else self.list_sort_order
+        if user_sort:
+            sort_order = user_sort.split(',')
+        else:
+            sort_order = self.list_sort_order
         filter_fields = self._default_filter()
         query = self.model.objects.all()
         query = utils.apply_sort_order(query, self.list_columns, sort_order)
@@ -651,7 +658,10 @@ class BaseDictionaryModelActions(BaseDictionaryActions):
         return result
 
     def get_rows(self, offset, limit, filter, user_sort=''):
-        sort_order = user_sort.split(',') if user_sort else self.list_sort_order
+        if user_sort:
+            sort_order = user_sort.split(',')
+        else:
+            sort_order = self.list_sort_order
         filter_fields = self._default_filter()
         query = utils.apply_sort_order(
             self.model.objects, self.list_columns, sort_order)
@@ -662,14 +672,6 @@ class BaseDictionaryModelActions(BaseDictionaryActions):
         result = {'rows': list(query.all()), 'total': total}
         return result
 
-#    def modify_rows_query(self, query, request, context):
-#        '''
-#        Модифицирует запрос на получение данных.
-#        Данный метод необходимо определить в
-#        дочерних классах.
-#        '''
-#        return query
-
     def get_row(self, id):
         assert isinstance(id, int)
         # Если id нет, значит нужно создать новый объект
@@ -679,7 +681,7 @@ class BaseDictionaryModelActions(BaseDictionaryActions):
             record = self.model.objects.get(id=id)
         return record
 
-    @transaction.commit_on_success
+    @atomic
     def save_row(self, obj):
         obj.save()
         return OperationResult(success=True)
@@ -688,19 +690,23 @@ class BaseDictionaryModelActions(BaseDictionaryActions):
         # Такая реализация обусловлена тем,
         # что IntegrityError невозможно отловить
         # до завершения транзакции, и приходится оборачивать транзакцию.
-        @transaction.commit_on_success
+        @atomic
         def delete_row_in_transaction(self, objs):
             message = ''
             if len(objs) == 0:
                 message = u'Элемент не существует в базе данных.'
             else:
                 for obj in objs:
-                    if (isinstance(obj, BaseObjectModel) or
-                        (hasattr(obj, 'safe_delete') and
-                        callable(obj.safe_delete))):
+                    if (
+                        isinstance(obj, BaseObjectModel) or
+                        (
+                            hasattr(obj, 'safe_delete') and
+                            callable(obj.safe_delete)
+                        )
+                    ):
                         try:
                             obj.safe_delete()
-                        except RelatedError, e:
+                        except RelatedError as e:
                             message = e.args[0]
                     else:
                         if not safe_delete(obj):
@@ -712,7 +718,7 @@ class BaseDictionaryModelActions(BaseDictionaryActions):
         # Тут пытаемся поймать ошибку из транзакции.
         try:
             return delete_row_in_transaction(self, objs)
-        except Exception, e:
+        except Exception as e:
             # Встроенный в Django IntegrityError
             # не генерируется. Кидаются исключения
             # специфичные для каждого драйвера БД.
@@ -749,7 +755,9 @@ class BaseEnumerateDictionary(BaseDictionaryActions):
     # Класс перечисление с которым работает справочник
     enumerate_class = None
 
-    list_paging = False  # Значений как правило мало и они влезают в одну страницу грида
+    # Значений как правило мало и они влезают в одну страницу грида
+    list_paging = False
+
     list_readonly = True
     list_columns = [('code', 'Код', 15),
                     ('name', 'Наименование')]
@@ -781,7 +789,7 @@ class BaseEnumerateDictionary(BaseDictionaryActions):
             ' defined in %s' % (id, self.enumerate_class))
         return id
 
-    #ISelectablePack
+    # ISelectablePack
     def get_display_text(self, key, attr_name=None):
         """
         Получить отображаемое значение записи
@@ -791,6 +799,6 @@ class BaseEnumerateDictionary(BaseDictionaryActions):
         text = self.enumerate_class.values.get(row_id, '')
         return text
 
-    #ISelectablePack
+    # ISelectablePack
     def get_record(self, key):
         return self.get_row(key)
