@@ -1,27 +1,16 @@
-#coding: utf-8
-"""
-Хелперы для отработки расширяемых конфигураций url'ов
-+++++++++++++++++++++++++++++++++++++++++++++++++++++
-"""
+# coding: utf-8
+u"""Хелперы для отработки расширяемых конфигураций url'ов."""
+from __future__ import absolute_import
 
+from importlib import import_module
 import collections
 import inspect
-
 import warnings
 
-from django.conf import settings
-from django.utils import importlib
-
-# совместимость с django 1.6
-try:
-    from django.conf.urls.defaults import patterns
-except ImportError:
-    from django.conf.urls import patterns
-
-
 from m3 import caching
-
-from m3.actions import ControllerCache, Action
+from m3.actions import Action
+from m3.actions import ControllerCache
+from m3_django_compat import get_installed_apps
 
 
 def _get_instance(obj):
@@ -46,12 +35,12 @@ def get_app_urlpatterns():
     Перехват исключительных ситуаций данной фунции необходимо осуществлять
     вручную в urls.py прикладных приложений
     '''
-    url_patterns = patterns('',)
+    url_patterns = []
 
-    for app_name in settings.INSTALLED_APPS:
+    for app_name in get_installed_apps():
         try:
-            module = importlib.import_module('.app_meta', app_name)
-        except ImportError, err:
+            module = import_module('.app_meta', app_name)
+        except ImportError as err:
             # по идее, такая ошибка возникает в
             # случае, если у нас для
             # установленного приложения
@@ -111,6 +100,7 @@ def get_url(action):
             break
     return action_data[1] if action_data else ''
 
+
 get_acton_url = get_url
 
 
@@ -142,9 +132,9 @@ def get_pack_by_url(url):
     return None
 
 
-#==============================================================================
+# =============================================================================
 # Кеш, используемый для хранения соответствия экшенов
-#==============================================================================
+# =============================================================================
 class ActionsNameCache(caching.IntegralRuntimeCache):
     '''
     Кеш, используемый для хранения соответствия имен экшенов и паков
