@@ -1,30 +1,39 @@
-#coding:utf-8
+# coding:utf-8
+from __future__ import absolute_import
 
 import datetime
 
-from django.db import models, connection, transaction, router, connections
-from django.db.models.query import QuerySet
+from django.db import connections
+from django.db import models
+from django.db import router
 from django.db.models.deletion import Collector
-
-from m3 import json_encode, RelatedError
+from django.db.models.query import QuerySet
+from m3 import RelatedError
+from m3 import json_encode
+from m3_django_compat import Manager
+from m3_django_compat import commit_unless_managed
+import six
 
 
 def safe_delete(model):
     """
     Функция выполняющая "безопасное" удаление записи из БД.
+
     В случае, если удаление не удалось по причине нарушения целостности,
     то возвращается false. Иначе, true
     к тому же функция пересчитывает MPTT индексы дерева
     т.к. стандартный пересчет запускается при вызове model_instance.delete()
     """
     models.signals.pre_delete.send(sender=model.__class__, instance=model)
+    db_alias = router.db_for_write(model.__class__, instance=model)
     try:
+        connection = connections[db_alias]
         cursor = connection.cursor()
         sql = "DELETE FROM %s WHERE id = %s" % (
             connection.ops.quote_name(model._meta.db_table), model.id)
         cursor.execute(sql)
-        transaction.commit_unless_managed()
-    except Exception, e:
+        commit_unless_managed(using=db_alias)
+    except Exception as e:
         # Встроенный в Django IntegrityError не генерируется.
         # Кидаются исключения, специфичные для каждого драйвера БД.
         # Но по спецификации PEP 249 все они называются IntegrityError
@@ -36,12 +45,12 @@ def safe_delete(model):
     # (т.к. стандартный пересчет вешается на метод self.delete()
     if hasattr(model, '_tree_manager') and callable(
             getattr(model._tree_manager, '_close_gap', None)):
-        #это, видимо, mptt модель
+        # это, видимо, mptt модель
         opts = model._meta
-        r = getattr(model, getattr(opts, 'right_attr', 'rght'))
-        l = getattr(model, getattr(opts, 'left_attr', 'lft'))
-        t = getattr(model, getattr(opts, 'tree_id_attr', 'tree_id'))
-        model._tree_manager._close_gap(r - l + 1, r, t)
+        right = getattr(model, getattr(opts, 'right_attr', 'rght'))
+        left = getattr(model, getattr(opts, 'left_attr', 'lft'))
+        tree = getattr(model, getattr(opts, 'tree_id_attr', 'tree_id'))
+        model._tree_manager._close_gap(right - left + 1, right, tree)
 
     models.signals.post_delete.send(sender=model.__class__, instance=model)
     return True
@@ -89,7 +98,7 @@ class BaseEnumerate(object):
         Используется для ограничения полей ORM и в качестве источника данных
         в ArrayStore и DataStore ExtJS
         """
-        return cls.values.items()
+        return list(cls.values.items())
 
     get_items = get_choices
 
@@ -99,7 +108,7 @@ class BaseEnumerate(object):
         Возвращает значение атрибута константы, которая используется в
         качестве ключа к словарю values
         """
-        if not isinstance(name, basestring):
+        if not isinstance(name, six.string_types):
             raise TypeError("'name' must be a string")
 
         if not name:
@@ -108,6 +117,7 @@ class BaseEnumerate(object):
         return cls.__dict__[name]
 
 
+@six.python_2_unicode_compatible
 class BaseObjectModel(models.Model):
     """
     Базовая модель для объектов системы.
@@ -120,9 +130,9 @@ class BaseObjectModel(models.Model):
         Отображение объекта по-умолчанию. Отличается от __unicode__ тем,
         что вызывается при json сериализации в m3.core.json.M3JSONEncoder
         """
-        return unicode(self)
+        return six.text_type(self)
 
-    def __unicode__(self):
+    def __str__(self):
         """ Определяет текстовое представление объекта """
         name = getattr(self, 'name', None) or getattr(self, 'fullname', None)
         if name:
@@ -163,7 +173,7 @@ class BaseObjectModel(models.Model):
         using = using or router.db_for_write(self.__class__, instance=self)
         collector = Collector(using=using)
         collector.collect([self])
-        return collector.data.items()
+        return list(collector.data.items())
 
     def delete_related(self, affected=None, using=None):
         """
@@ -218,8 +228,8 @@ class ForUpdateQuerySet(QuerySet):
             sql.rstrip() + ' FOR UPDATE', params)
 
 
-class ForUpdateManager(models.Manager):
-    def get_query_set(self):
+class ForUpdateManager(Manager):
+    def get_queryset(self):
         return ForUpdateQuerySet(self.model, using=self._db)
 ##############################################################
 
@@ -289,7 +299,7 @@ class ObjectState(BaseEnumerate):
     values = {VALID: u'Действует', CLOSED: u'Закрыта', DRAFT: u'Черновик'}
 
 
-class ObjectManager(models.Manager):
+class ObjectManager(Manager):
     """
     Менеджер запросов к записям справочника
     Фильтрует записи по периоду действия и состоянию
@@ -311,17 +321,17 @@ class ObjectManager(models.Manager):
         else:
             self.query_state = self.get_default_state()
 
-    def get_query_set(self):
+    def get_queryset(self):
         # если указывали дату,
         # то отфильтруем на дату, иначе только по состоянию
         if self.query_on_date:
-            return super(ObjectManager, self).get_query_set().filter(
+            return super(ObjectManager, self).get_queryset().filter(
                 begin__lte=self.query_on_date,
                 end__gt=self.query_on_date,
                 state__in=self.query_state
             )
         else:
-            return super(ObjectManager, self).get_query_set().filter(
+            return super(ObjectManager, self).get_queryset().filter(
                 state__in=self.query_state
             )
 
