@@ -1,7 +1,9 @@
-#coding:utf-8
+# coding:utf-8
+from __future__ import absolute_import
 
 from django.db.models import signals as model_signals
 
+
 try:
     import mptt
 except ImportError:
@@ -59,7 +61,6 @@ def rebuild_mptt_tree(
 
     def build_node(model, opts, parent_id, tree_id, left, level):
         qs = model_manager.filter(**{opts.parent_attr: parent_id})
-        #print 'tree=',tree_id,'left=',left,'level=',level
         right = left
         for node in qs:
             setattr(node, opts.tree_id_attr, tree_id)
@@ -77,9 +78,7 @@ def rebuild_mptt_tree(
     opts = model._meta
     qs = model_manager.filter(**{'%s__isnull' % opts.parent_attr: True})
     tree_id = 1
-    #l = len(qs)
     for node in qs:
-        #print 'tree=',tree_id, l
         setattr(node, opts.tree_id_attr, tree_id)
         setattr(node, opts.left_attr, 1)
         setattr(node, opts.level_attr, 0)
