@@ -1,14 +1,15 @@
-# -*- coding: utf-8 -*-
-"""
-Static files finders
-"""
+# coding: utf-8
+"""Static files finders."""
+from __future__ import absolute_import
+
+from collections import OrderedDict
+from importlib import import_module
 import os
-from importlib import import_module
 
-from django.contrib.staticfiles.finders import AppDirectoriesFinder, BaseFinder
-from django.core.files.storage import FileSystemStorage
-from django.utils.datastructures import SortedDict
 from django.conf import settings
+from django.contrib.staticfiles.finders import AppDirectoriesFinder
+from django.contrib.staticfiles.finders import BaseFinder
+from django.core.files.storage import FileSystemStorage
 
 
 class RecursiveAppDirectoriesFinder(AppDirectoriesFinder):
@@ -27,7 +28,7 @@ class RecursiveAppDirectoriesFinder(AppDirectoriesFinder):
 
     def __init__(self, apps=None, *args, **kwargs):
         self.apps = []
-        self.storages = SortedDict()
+        self.storages = OrderedDict()
         visited = set()
 
         def traverse(path, root=False):
