@@ -1,11 +1,9 @@
-#coding:utf-8
-'''
-@author: pirogov
-'''
+# coding:utf-8
+from __future__ import absolute_import
+
 import sys
 
 from django.core.management.base import BaseCommand
-
 from m3.actions import ControllerCache
 
 
